django-comments-tree — django-comments-tree 2.4.0 documentation

# django-comments-tree

A Django pluggable application that adds comments to your project. It extends the once official Django Comments Framework with the following features:

1. Comments model based on django-treebeard to provide a robust and fast threaded and nested comment structure.

2. Efficiently associate a comment tree with any model through a link table which avoids populating each comment with extra link data.

3. Customizable maximum thread level, either for all models or on a per app.model basis.

4. Optional notifications on follow-up comments via email.

5. Mute links to allow cancellation of follow-up notifications.

6. Comment confirmation via email when users are not authenticated.

7. Comments hit the database only after they have been confirmed.

8. Registered users can like/dislike comments and can suggest comments removal.

9. Template tags to list/render the last N comments posted to any given list of app.model pairs.

10. Emails sent through threads (can be disable to allow other solutions, like a Celery app).

11. Fully functional JavaScript plugin using ReactJS, jQuery, Bootstrap, Remarkable and MD5.

## Contents

- Quick start guide
- Tutorial
- Demo projects
- Control logic
- Web API
- JavaScript plugin
- Filters and template tags
- Migrating to django-comments-tree
- Customizing django-comments-tree
- Internationalization
- Settings
- Templates